==> doccheck_basic-8.x-1.7.tar.gz: doccheck_basic/src/DoccheckBasicCommon.php <==
<?php

namespace Drupal\doccheck_basic;

use Drupal\Core\Language\LanguageManager;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RedirectDestinationInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\doccheck_basic\Form\SettingsForm;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Contains \Drupal\doccheck_basic\DoccheckBasicCommon.
 */
class DoccheckBasicCommon implements ContainerFactoryPluginInterface {
  use StringTranslationTrait;

  /**
   * The variable containing the conditions configuration.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private $config;

  /**
   * The variable containing the logging.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactory
   */
  private $logger;

  /**
   * The variable containing the current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The variable containing the request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The variable containing the language manager.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * The redirect destination service.
   *
   * @var \Drupal\Core\Routing\RedirectDestinationInterface
   */
  protected $redirectDestination;

  /**
   * Dependency injection through the constructor.
   *
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger
   *   The logger service.
   * @param \Drupal\Core\Config\ImmutableConfig $config
   *   The config service.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   The current user service.
   * @param \Symfony\Component\HttpFoundation\Request $requestStack
   *   The request stack service.
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   *   The language service.
   * @param \Drupal\Core\Routing\RedirectDestinationInterface $redirect_destination
   *   The redirect destination service.
   */
  public function __construct(LoggerChannelFactoryInterface $logger,
  ImmutableConfig $config,
  AccountProxyInterface $currentUser,
  Request $requestStack,
  LanguageManager $languageManager,
  RedirectDestinationInterface $redirect_destination
  ) {
    $this->logger = $logger;
    $this->config = $config;
    $this->currentUser = $currentUser;
    $this->requestStack = $requestStack;
    $this->languageManager = $languageManager;
    $this->redirectDestination = $redirect_destination;
  }

  /**
   * Dependency injection create.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($container->get('logger.factory'),
    $container->get('config.factory'),
    $container->get('current_user'),
    $container->get('request_stack'),
    $container->get('language_manager'),
    $container->get('redirect.destination')
    );
  }

  /**
   * Defines doccheck login for block and page.
   */
  public function doccheckBasicLogin($template) {
    \Drupal::service('page_cache_kill_switch')->trigger();
    if (strlen($this->config->get('dc_loginid')) < 1) {
      $err_msg = $this->t('DocCheck Login ID not set');
      $this->logger->get('doccheck_basic')->error($err_msg);
      \Drupal::messenger()->addMessage($err_msg, 'error');
      return [
        '#markup' => '',
        '#cache' => [
          'max-age' => 0,
        ],
      ];
    }

    if ($this->currentUser->getAccount()->isAnonymous()) {
      $this->requestStack->getSession()->set('forced', TRUE);
    }
    elseif ($template === 'page') {
      return [
        '#theme' => 'doccheck_basic',
        '#loggedin' => TRUE,
        '#dctemplate' => NULL,
        '#width' => NULL,
        '#height' => NULL,
        '#language' => NULL,
        '#loginid' => NULL,
        '#devmode' => NULL,
        '#cache' => [
          'max-age' => 0,
        ],
      ];

    }
    if ($template === 'page' && $this->config->get('dc_noderedirect') !== '') {
      $this->requestStack->getSession()->set('dc_page',
        $this->config->get('dc_noderedirect'));
    }
    else {
      $this->requestStack->getSession()->set('dc_page', $this->redirectDestination->get());
    }

    return [
      '#theme' => 'doccheck_basic',
      '#loggedin' => FALSE,
      '#dctemplate' => ($this->config->get('dc_template') == SettingsForm::CUSTOM_TEMPLATE) ? ($this->config->get('dc_template_custom')) : ($this->config->get('dc_template')),
      '#width' => $this->templateSize($this->config->get('dc_template'), 'w'),
      '#height' => $this->templateSize($this->config->get('dc_template'), 'h'),
      '#language' => $this->languageManager->getCurrentLanguage()->getId(),
      '#loginid' => $this->config->get('dc_loginid'),
      '#devmode' => ($this->config->get('dc_devmode')) ?
      ('<a href="' . $this->requestStack->getSchemeAndHttpHost() . '/_dc_callback">' . $this->t('Development mode login') . '</a>') :
      (''),
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

  /**
   * Returns width or height of doccheck template.
   */
  public function templateSize($type, $dimension) {
    $template_size = [
      's_red' => ['w' => 156, 'h' => 203],
      'm_red' => ['w' => 311, 'h' => 188],
      'l_red' => ['w' => 424, 'h' => 215],
      'xl_red' => ['w' => 467, 'h' => 231],
      'login_s' => ['w' => 156, 'h' => 203],
      'login_m' => ['w' => 311, 'h' => 195],
      'login_l' => ['w' => 424, 'h' => 215],
      'login_xl' => ['w' => 467, 'h' => 231],
      SettingsForm::CUSTOM_TEMPLATE => [
        'w' => $this->config->get('dc_template_custom_width'),
        'h' => $this->config->get('dc_template_custom_height'),
      ],
    ];
    return (isset($template_size[$type])) ?
      ($template_size[$type][$dimension]) : (FALSE);
  }

}

==> doccheck_basic-8.x-1.8.tar.gz: doccheck_basic/src/DoccheckBasicCommon.php <==
<?php

namespace Drupal\doccheck_basic;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Language\LanguageManager;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RedirectDestinationInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\doccheck_basic\Form\SettingsForm;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Contains \Drupal\doccheck_basic\DoccheckBasicCommon.
 */
class DoccheckBasicCommon implements ContainerFactoryPluginInterface {
  use StringTranslationTrait;

  /**
   * The variable containing the conditions configuration.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * The variable containing the conditions configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The variable containing the logging.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The variable containing the current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The variable containing the request stack.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * The variable containing the language manager.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * The redirect destination service.
   *
   * @var \Drupal\Core\Routing\RedirectDestinationInterface
   */
  protected $redirectDestination;

  /**
   * Dependency injection through the constructor.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger service.
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   *   The config service.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   The current user service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   *   The request stack service.
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   *   The language service.
   * @param \Drupal\Core\Routing\RedirectDestinationInterface $redirect_destination
   *   The redirect destination service.
   */
  public function __construct(LoggerInterface $logger,
  ConfigFactory $configFactory,
  AccountProxyInterface $currentUser,
  RequestStack $requestStack,
  LanguageManager $languageManager,
  RedirectDestinationInterface $redirect_destination
  ) {
    $this->logger = $logger;
    $this->configFactory = $configFactory;
    $this->config = $configFactory->get('config.doccheck_basic');
    $this->currentUser = $currentUser;
    $this->request = $requestStack->getCurrentRequest();
    $this->languageManager = $languageManager;
    $this->redirectDestination = $redirect_destination;
  }

  /**
   * Dependency injection create.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($container->get('logger.factory'),
    $container->get('config.factory'),
    $container->get('current_user'),
    $container->get('request_stack'),
    $container->get('language_manager'),
    $container->get('redirect.destination')
    );
  }

  /**
   * Defines doccheck login for block and page.
   */
  public function doccheckBasicLogin($template) {
    \Drupal::service('page_cache_kill_switch')->trigger();
    if (strlen($this->config->get('dc_loginid')) < 1) {
      $err_msg = $this->t('DocCheck Login ID not set');
      $this->logger->error($err_msg);
      \Drupal::messenger()->addMessage($err_msg, 'error');
      return [
        '#markup' => '',
        '#cache' => [
          'max-age' => 0,
        ],
      ];
    }

    if ($this->currentUser->getAccount()->isAnonymous()) {
      $this->request->getSession()->set('forced', TRUE);
    }
    elseif ($template === 'page') {
      return [
        '#theme' => 'doccheck_basic',
        '#loggedin' => TRUE,
        '#dctemplate' => NULL,
        '#width' => NULL,
        '#height' => NULL,
        '#language' => NULL,
        '#loginid' => NULL,
        '#devmode' => NULL,
        '#cache' => [
          'max-age' => 0,
        ],
      ];

    }
    if ($template === 'page' && $this->config->get('dc_noderedirect') !== '') {
      $this->request->getSession()->set('dc_page',
        $this->config->get('dc_noderedirect'));
    }
    else {
      $this->request->getSession()->set('dc_page', $this->redirectDestination->get());
    }

    return [
      '#theme' => 'doccheck_basic',
      '#loggedin' => FALSE,
      '#dctemplate' => ($this->config->get('dc_template') == SettingsForm::CUSTOM_TEMPLATE) ? ($this->config->get('dc_template_custom')) : ($this->config->get('dc_template')),
      '#width' => $this->templateSize($this->config->get('dc_template'), 'w'),
      '#height' => $this->templateSize($this->config->get('dc_template'), 'h'),
      '#language' => $this->languageManager->getCurrentLanguage()->getId(),
      '#loginid' => $this->config->get('dc_loginid'),
      '#devmode' => ($this->config->get('dc_devmode')) ?
      ('<a href="' . $this->request->getSchemeAndHttpHost() . '/_dc_callback">' . $this->t('Development mode login') . '</a>') :
      (''),
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

  /**
   * Returns width or height of doccheck template.
   */
  public function templateSize($type, $dimension) {
    $template_size = [
      's_red' => ['w' => 156, 'h' => 203],
      'm_red' => ['w' => 311, 'h' => 188],
      'l_red' => ['w' => 424, 'h' => 215],
      'xl_red' => ['w' => 467, 'h' => 231],
      'login_s' => ['w' => 156, 'h' => 203],
      'login_m' => ['w' => 311, 'h' => 195],
      'login_l' => ['w' => 424, 'h' => 215],
      'login_xl' => ['w' => 467, 'h' => 231],
      SettingsForm::CUSTOM_TEMPLATE => [
        'w' => $this->config->get('dc_template_custom_width'),
        'h' => $this->config->get('dc_template_custom_height'),
      ],
    ];
    return (isset($template_size[$type])) ?
      ($template_size[$type][$dimension]) : (FALSE);
  }

}
